#!/bin/bash
#
# Migrate (mirror) a remote repository
#
# migrate-repo.sh <reponame> <organisation> [<target organisation>]
#
inifilename=$(echo ~)"/.smegit/config"
if [ ! -e $inifilename ] ; then
  # Not here, look at system default
  if [ ! -e /etc/smegit.ini ] ; then 
    echo "No ini file found $inifiename or /etc/smegit.ini"
    echo "git_mirror-repo.sh <reponame> <organisation> [<target organisation>]"
    exit 1
  else
    initfilename="/etc/smegit.ini"
  fi
fi 

while read -r line || [[ -n "$line" ]]; do
    if [[ $line =~ ^\[.*\]$ ]]
    then
        section=${line#*[}
        section=${section%]*}
    else
        if [[ $line =~ ^[^#]*= ]]
        then
            key=${line%=*}
            value=${line#*=}
            declare "${section}_${key}=$value"
        fi
    fi
done < $inifilename

if [[ -z $1 ]] ; then
	echo "git_migrate-repo.sh <reponame> <organisation> [<target organization>]"
	echo "will migrate repo to local user unless <target organisation> specified"
	exit 0
fi
DEBUG=
if [ ${smegit_DEBUG} == true ] ; then DEBUG=true ; fi
if [ $DEBUG ] ; then echo "found ini file: $inifilename" ; fi

curlsilent="-s"
if [ $DEBUG ] ; then curlsilent= ; fi

REMOTEACCESSTOKEN=${remote_GITEAACCESSTOKEN}
LOCALACCESSTOKEN=${local_GITEAACCESSTOKEN}
REMOTEGITEAHOST=${remote_GITEAHOST}
CLONEADDRESS=$REMOTEGITEAHOST/$2/$1.git
LOCALGITEAHOST=${local_GITEAHOST}
TARGETORG=${local_USER}
if [ $3 ] ; then TARGETORG=$3 ; fi

# check that the TARGETORG exists
if [ $DEBUG ] ; then echo "checking if $TARGETORG exists on $LOCALGITEAHOST" ; fi
RESPONSE=$(curl $curlsilent -o /dev/null -w "%{http_code}" $LOCALGITEAHOST/$TARGETORG)
if [ $DEBUG ] ; then echo "RESPONSE=$RESPONSE" ; fi
if [[ "$RESPONSE" != "200" ]] ; then
    echo "$TARGETORG does not exist on $LOCALGITEAHOST"
    exit 1
fi 

# And check if this repo already exists on the target
if [ $DEBUG ] ; then echo "checking if $TARGETORG/$1 already exists on $LOCALGITEAHOST" ; fi
RESPONSE=$(curl $curlsilent -o /dev/null -w "%{http_code}" $LOCALGITEAHOST/$TARGETORG/$1)
if [ $DEBUG ] ; then echo "RESPONSE=$RESPONSE" ; fi
if [ "$RESPONSE" == "200" ] ; then
	echo "Repository $TARGETORG/$1 already exists on $LOCALGITEAHOST - cannot migrate"
	exit 1
fi

if [ $DEBUG ] ; then echo "Mirroring $2/$1 as $TARGETORG/$1 on $LOCALGITEAHOST" ; fi
RESPONSE=$(curl $curlsilent -k -X 'POST' \
  "$LOCALGITEAHOST/api/v1/repos/migrate" \
  -H 'accept: application/json' \
  -H "Authorization: token $LOCALACCESSTOKEN" \
  -H 'Content-Type: application/json' \
  -d '{
  "auth_token": "'"$REMOTEACCESSTOKEN"'",
  "clone_addr": "'"$CLONEADDRESS"'",
  "issues": true,
  "labels": true,
  "lfs": true,
  "milestones": true,
  "mirror": true,
  "private": false,
  "pull_requests": true,
  "releases": true,
  "repo_name": "'"$1"'",
  "repo_owner": "'"$TARGETORG"'",
  "service": "git",
  "uid": 0,
  "wiki": true
}')

if [ $DEBUG ] ; then echo $? $RESPONSE ; fi

# And check if this repo is there
if [ $DEBUG ] ; then echo "checking that $TARGETORG/$1 exists" ; fi
RESPONSE=$(curl $curlsilent -o /dev/null -w "%{http_code}" $LOCALGITEAHOST/$TARGETORG/$1)
if [ $DEBUG ] ; then echo "RESPONSE=$RESPONSE" ; fi
if [ "$RESPONSE" == "200" ] ; then
	echo "Repository $TARGETORG/$1 has been created and mirrors $2/$1"
else
	echo "migrate-repo was unable to migrate $2/$1 sucessfully"
	exit 1
fi

